@@ -3,6 +3,8 @@ from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 
+from compat import AUTH_USER_MODEL
+
 class VoteManger(models.Manager):
     def filter(self, *args, **kwargs):
         if kwargs.has_key('content_object'):
@@ -15,7 +17,7 @@ class VoteManger(models.Manager):
         return super(VoteManger, self).filter(*args, **kwargs)
     
 class Vote(models.Model):
-    user = models.ForeignKey(User)
+    user = models.ForeignKey(AUTH_USER_MODEL)
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
     content_object = generic.GenericForeignKey()
